==> mongo-cxx-driver-r3.8.0.tar.gz: mongo-cxx-driver-r3.8.0/docs/content/_index.md <==
+++
date = "2016-08-15T16:11:58+05:30"
title = "MongoDB C++ Driver Manual"
type = "index"
+++

# MongoDB C++ Driver

Welcome to the MongoDB C++ driver.  On this site, you'll find documentation
to help you get the most from MongoDB and C++.  If you're just starting
out, take a look at these pages first:

* [Installing mongocxx]({{< ref "/mongocxx-v3/installation" >}})
* [Quick-start tutorial]({{< ref "/mongocxx-v3/tutorial" >}})

## Driver status by family and version

Stability indicates whether this driver is recommended for production use.
Currently, no drivers guarantee API or ABI stability.

| Family/version       | Stability   | Development         | Purpose                             |
| -------------------- | ----------- | ------------------- | ----------------------------------- |
| (repo master branch) | Unstable    | Active development  | New feature development             |
| mongocxx 3.7.x       | Stable      | Bug fixes only      | Current stable C++ driver release   |
| mongocxx 3.6.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.5.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.4.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.3.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.2.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.1.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.0.x       | Stable      | None                | Previous stable C++ driver release  |

## MongoDB compatibility

Compatibility of each C++ driver version with each MongoDB server is documented in the [MongoDB manual](https://docs.mongodb.com/drivers/cxx#mongodb-compatibility).

## License

MongoDB C++ drivers are available under the terms of the Apache License, version 2.0.

==> mongo-cxx-driver-r3.9.0.tar.gz: mongo-cxx-driver-r3.9.0/docs/content/_index.md <==
+++
date = "2016-08-15T16:11:58+05:30"
title = "MongoDB C++ Driver Manual"
type = "index"
+++

# MongoDB C++ Driver

Welcome to the MongoDB C++ driver.  On this site, you'll find documentation
to help you get the most from MongoDB and C++.  If you're just starting
out, take a look at these pages first:

* [Installing mongocxx]({{< ref "/mongocxx-v3/installation" >}})
* [Quick-start tutorial]({{< ref "/mongocxx-v3/tutorial" >}})

## Driver status by family and version

Stability indicates whether this driver is recommended for production use.
Currently, no drivers guarantee API or ABI stability.

| Family/version       | Stability   | Development         | Purpose                             |
| -------------------- | ----------- | ------------------- | ----------------------------------- |
| (repo master branch) | Unstable    | Active development  | New feature development             |
| mongocxx 3.8.x       | Stable      | Bug fixes only      | Current stable C++ driver release   |
| mongocxx 3.7.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.6.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.5.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.4.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.3.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.2.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.1.x       | Stable      | None                | Previous stable C++ driver release  |
| mongocxx 3.0.x       | Stable      | None                | Previous stable C++ driver release  |

## MongoDB compatibility

Compatibility of each C++ driver version with each MongoDB server is documented in the [MongoDB manual](https://www.mongodb.com/docs/drivers/cxx#mongodb-compatibility).

## License

MongoDB C++ drivers are available under the terms of the Apache License, version 2.0.
